write_portable

Function write_portable 

pub fn write_portable(path: &Path, key: &MasterKey) -> Result<()>
Writes key to path in the portable form, owner-only.

Errors

Error::Io when the file cannot be created or written.