unset

Function unset 

pub fn unset(config: &mut File, key: &str) -> Result<()>
Removes a dotted key, if it is there at all.

Errors

Error::Config when the key names a section that cannot be addressed.