read_portable

Function read_portable 

pub fn read_portable(path: &Path) -> Result<MasterKey>
Reads a key from a portable file.

Errors

Error::Usage when the file the user named is not there, Error::Io when it cannot be read, Error::Format when it is not a key file this build understands.