forget_stat

Function forget_stat 

pub fn forget_stat(
    index_path: &Path,
    hash: Kind,
    paths: &[Vec<u8>],
) -> Result<Outcome>
Makes git re-read paths by forgetting the size it cached for them.

paths are repository-relative and spelled with forward slashes, the way the index stores them.

Errors

Error::Io when the index exists but cannot be read or replaced.